@@ -20,7 +20,6 @@ class DataMediator:
     [Args]
         `dataframe` (DataFrame): Data to split, balance, and take holdout \n
         `testProportion` (float): Percentage of data from experimental & control sets to holdout. \n
-        `IDlabel` (str): Column name of IDs in the dataframe. \n
         `controlIDs` (list[str]): List of sample IDs in the control set. \n
         `experimentalIDs` (list[str]): List of sample IDs in the experimental set. \n
         `randomSeed` (int): Seed number to replicate psuedorandom sampling.
@@ -37,7 +36,6 @@ class DataMediator:
         self,
         dataframe: DataFrame,
         testProportion: float,
-        IDlabel: str,
         controlIDs: list,
         experimentalIDs: list,
         randomSeed: int,
@@ -45,7 +43,6 @@ class DataMediator:
     ) -> None:
         self.dataframe = dataframe
         self.testProportion = testProportion
-        self.IDlabel = IDlabel
         self.randomSeed = randomSeed
 
         # split experimental & control data with given IDs
@@ -82,6 +79,7 @@ class DataMediator:
     @staticmethod
     def transposeDataFrame(
         dataframe,
+        sampleIndexLabel,
         columnToTranspose: str,
         columnsToDrop: Union[List[str], slice] = None,
     ) -> DataFrame:
@@ -98,7 +96,7 @@ class DataMediator:
                 else columnsToDrop
             )
         ).T.iloc[1:, :]
-        columnIDs = dataframe[columnToTranspose].tolist()
+        columnIDs = dataframe[columnToTranspose].tolist().insert(0, sampleIndexLabel)
 
         # set new indices
         transposed.columns = columnIDs
@@ -271,21 +269,32 @@ class DataMediator:
                 stratify=allLabels if stratifyByClass else None,
                 random_state=self.randomSeed,
             )
+            (
+                self.train,
+                self.validation,
+                self.trainLabels,
+                self.validationLabels,
+            ) = train_test_split(
+                postHoldoutData.astype(int),
+                postHoldoutLabels,
+                test_size=testProportion,  # percentage if less than 1
+                stratify=postHoldoutLabels if stratifyByClass else None,
+                random_state=self.randomSeed,
+            )
         else:
             testProportion = self.testProportion
-
-        (
-            self.train,
-            self.validation,
-            self.trainLabels,
-            self.validationLabels,
-        ) = train_test_split(
-            postHoldoutData.astype(int),
-            postHoldoutLabels,
-            test_size=testProportion,  # percentage if less than 1
-            stratify=postHoldoutLabels if stratifyByClass else None,
-            random_state=self.randomSeed,
-        )
+            (
+                self.train,
+                self.validation,
+                self.trainLabels,
+                self.validationLabels,
+            ) = train_test_split(
+                allData.astype(int),
+                allLabels,
+                test_size=testProportion,  # percentage if less than 1
+                stratify=postHoldoutLabels if stratifyByClass else None,
+                random_state=self.randomSeed,
+            )
 
     def loadPredictions(self, probabilities: list, dataGroup: str = "test"):
         """
